/*
 *	Copyright (C) 2007, 2008, 2009. PARP Research Group.
 *	<http://perception.inf.um.es>
 *	University of Murcia, Spain.
 *
 *	This file is part of the QVision library.
 *
 *	QVision is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU Lesser General Public License as
 *	published by the Free Software Foundation, version 3 of the License.
 *
 *	QVision is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU Lesser General Public License for more details.
 *
 *	You should have received a copy of the GNU Lesser General Public
 *	License along with QVision. If not, see <http://www.gnu.org/licenses/>.
 */

/// @file qvworkerinterfacesmall.cpp
/// @brief File from the QVision library.
/// @author PARP Research Group. University of Murcia, Spain.

#include <qvgui/qvworkerinterfacesmall.h>

QVWorkerInterfaceSmall::QVWorkerInterfaceSmall(QVWorker *worker, QWidget *parent): QWidget(parent), cpuPlot(0)
	{
	qDebug() << "QVWorkerInterfaceSmall::QVWorkerInterfaceSmall("<< worker->getName() << ")";
	form.setupUi(this);

	setWindowTitle(worker->getName());
	//form.groupBox->setTitle(worker->getName());
	this->worker = worker;
	isGroupMaster = worker->isSequentialGroupMaster();

	if (worker->isStatsEnabled()) {
		this->cpuPlot = new QVCPUPlot("CPU performance plot of: " + worker->getName(), true, false);
		worker->linkProperty("cpu stats", this->cpuPlot);
		this->cpuPlot->init();
		connect(form.stat_button,SIGNAL(toggled(bool)),cpuPlot,SLOT(setVisible(bool)));
		connect(cpuPlot,SIGNAL(closed()),form.stat_button,SLOT(toggle()));
	}
	else
		form.stat_button->setEnabled(false);

/*	this->cpuPlotSmall = new QVCPUPlot("Small cpu plot of: " + worker->getName(), false);
	this->cpuPlotSmall->linkProperty(*worker);
	this->cpuPlotSmall->setFixedHeight(75);
	form.vboxLayout->addWidget(this->cpuPlotSmall);*/

	// Connect worker slots with form's buttons
	connect(form.pause_button,SIGNAL(pressed()),worker,SLOT(pause()),Qt::QueuedConnection);
	connect(form.play_button,SIGNAL(pressed()),worker,SLOT(unPause()),Qt::QueuedConnection);
	connect(form.next_button,SIGNAL(pressed()),worker,SLOT(step()),Qt::QueuedConnection);
	connect(form.stop_button, SIGNAL(pressed()),worker,SLOT(stop()),Qt::QueuedConnection);
	connect(form.finish_button, SIGNAL(pressed()),this,SLOT(finishWorker()),Qt::QueuedConnection);

	// Connecting slot with worker update signal
	connect(worker,SIGNAL(endIteration(uint, int)),this,SLOT(newIterationSlot()),Qt::QueuedConnection);
	connect(worker,SIGNAL(statusUpdate(QVWorker::TWorkerStatus)),
		this,SLOT(statusUpdate(QVWorker::TWorkerStatus)),Qt::QueuedConnection);

	statusUpdate(worker->getStatus());

	show();
	qDebug() << "QVWorkerInterfaceSmall::QVWorkerInterfaceSmall(" << worker->getName() << ") <- return";
	}

QVWorkerInterfaceSmall::~QVWorkerInterfaceSmall()
	{
		if (this->cpuPlot) delete this->cpuPlot;
	}

void QVWorkerInterfaceSmall::finishWorker()
	{
		qvApp->quitWorker(worker);
	}

void QVWorkerInterfaceSmall::newIterationSlot()
	{ form.iterationsLabel->setText(QString("Iteration: ")+QString().setNum(worker->getIteration())); }

void QVWorkerInterfaceSmall::statusUpdate(QVWorker::TWorkerStatus status)
	{
	isGroupMaster = worker->isSequentialGroupMaster();
	if (!isGroupMaster) {
		form.finish_button->setEnabled(FALSE);
		form.stop_button->setEnabled(FALSE);
		form.pause_button->setEnabled(FALSE);
		form.play_button->setEnabled(FALSE);
		form.next_button->setEnabled(FALSE);
		}
	else {
		switch(status)
			{
			case QVWorker::Finished:
				form.finish_button->setEnabled(FALSE);
				form.stop_button->setEnabled(FALSE);
				form.pause_button->setEnabled(FALSE);
				form.play_button->setEnabled(FALSE);
				form.next_button->setEnabled(FALSE);
				break;
	
			case QVWorker::Stoped:
				form.finish_button->setEnabled(TRUE);
				form.stop_button->setEnabled(FALSE);
				form.pause_button->setEnabled(FALSE);
				form.play_button->setEnabled(FALSE);
				form.next_button->setEnabled(FALSE);
				break;
	
			case QVWorker::Running:
				form.finish_button->setEnabled(TRUE);
				form.stop_button->setEnabled(TRUE);
				form.pause_button->setEnabled(TRUE);
				form.play_button->setEnabled(FALSE);
				form.next_button->setEnabled(FALSE);
				break;
	
			case QVWorker::RunningOneStep:
			case QVWorker::Paused:
				form.finish_button->setEnabled(TRUE);
				form.stop_button->setEnabled(TRUE);
				form.pause_button->setEnabled(FALSE);
				form.play_button->setEnabled(TRUE);
				form.next_button->setEnabled(TRUE);
				break;
	
			default:
				break;
			}
		}
	}

