/*
 *	Copyright (C) 2007, 2008, 2009. PARP Research Group.
 *	<http://perception.inf.um.es>
 *	University of Murcia, Spain.
 *
 *	This file is part of the QVision library.
 *
 *	QVision is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU Lesser General Public License as
 *	published by the Free Software Foundation, version 3 of the License.
 *
 *	QVision is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU Lesser General Public License for more details.
 *
 *	You should have received a copy of the GNU Lesser General Public
 *	License along with QVision. If not, see <http://www.gnu.org/licenses/>.
 */

/// @file qvcpustat.h
/// @brief File from the QVision library.
/// @author PARP Research Group. University of Murcia, Spain.

#ifndef QVCPUSTAT_H
#define QVCPUSTAT_H
#include <QStringList>

class QVStatControler;

#ifndef DOXYGEN_IGNORE_THIS
class QVStat : public QObject
{
Q_OBJECT
friend class QVStatControler;

public:
	QVStat(): QObject(), lastOrder(0), flagOrder(), flagNames(), stats() { }
	QVStat(const QVStat &other): QObject(), lastOrder(other.lastOrder), flagOrder(other.flagOrder), flagNames(other.flagNames), stats(other.stats) { }

	QList<int> getFlagOrder() const { return flagOrder; }
	QStringList getFlagNames() const { return flagNames; }
	QList<double> getLastStats() const { return stats; }

protected:
	void addFlag(int pos, QString name);
	void setValue(int pos, double value);

private:
	int lastOrder;
	QList<int> flagOrder;
	QStringList flagNames;
	QList<double> stats;
};
#endif
#endif

